@@ -63,6 +63,11 @@ GDALcall <- function(object, option, ...) {
 
 
 .gd_transform <- function(projfrom, projto, n, x, y, z=NULL) {
+# pkgdown work-around
+  if (is.na(get("has_proj_def.dat", envir=.RGDAL_CACHE))) {
+    assign("has_proj_def.dat", .Call("PROJ4_proj_def_dat_Installed",
+      PACKAGE="rgdal"), envir=.RGDAL_CACHE)
+  }
   if (!get("has_proj_def.dat", envir=.RGDAL_CACHE)) {
       projfrom <- proj_def_bug_fix(projfrom)
       projto <- proj_def_bug_fix(projto)
@@ -73,6 +78,11 @@ GDALcall <- function(object, option, ...) {
 
 # exported version
 rawTransform <- function(projfrom, projto, n, x, y, z=NULL) {
+# pkgdown work-around
+        if (is.na(get("has_proj_def.dat", envir=.RGDAL_CACHE))) {
+          assign("has_proj_def.dat", .Call("PROJ4_proj_def_dat_Installed",
+          PACKAGE="rgdal"), envir=.RGDAL_CACHE)
+        }
         if (!get("has_proj_def.dat", envir=.RGDAL_CACHE)) {
             projfrom <- proj_def_bug_fix(projfrom)
             projto <- proj_def_bug_fix(projto)
